unit WpMain2;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TMainForm = class(TForm)
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    BitmapFolder: String;
    BitmapList: TStringList;
    procedure FindBitmaps(Folder: String);
    procedure ChangeWallpaper(Wallpaper: String);
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses
  IniFiles{, Registry};

const
  IniFileName: String = 'Wallpap2.ini';

{---------------------- TMainForm ---------------------}

procedure TMainForm.FormCreate(Sender: TObject);
var
  I: Integer;
  IniFile: TIniFile;
begin
  BitmapList := TStringList.Create;
  IniFile := TIniFile.Create(IniFileName);
  BitmapFolder := IniFile.ReadString('Bitmap folder', 'Folder', 'c:\windows');
  IniFile.Free;
  FindBitmaps(BitmapFolder);

  // We now have a list of bitmap names (maybe)
  if BitmapList.Count > 0 then
  begin
    Randomize;
    I := Random(BitmapList.Count);
    ChangeWallpaper(BitmapList[I]);
  end
  else
    MessageDlg('No bitmaps in specified folder: ' + BitmapFolder, mtError, [mbOk], 0);

  // Finally close the app.
  Application.Terminate;
end;


procedure TMainForm.FormDestroy(Sender: TObject);
var
  IniFile: TIniFile;
begin
  IniFile := TIniFile.Create(IniFileName);
  IniFile.WriteString('Bitmap folder', 'Folder', BitmapFolder);
  IniFile.Free;
  BitmapList.Free;
end;


procedure TMainForm.FindBitmaps(Folder: String);
var
  Found: Integer;
  SearchRec: TSearchRec;
begin
  BitmapList.Clear;
  // First File
  Found := FindFirst(Folder+'\*.bmp', faAnyFile, SearchRec);
  while Found = 0 do
  begin
    // Don't get the special directories ('.' and '..')
    if (SearchRec.Name <> '.') and (SearchRec.Name <> '..') then
      BitmapList.Add(Folder+'\'+SearchRec.Name);
    Found := FindNext(SearchRec);
  end;
  FindClose(SearchRec);
end;


procedure TMainForm.ChangeWallpaper(Wallpaper: string);
begin
  SystemParametersInfo(SPI_SETDESKWALLPAPER, 0, PChar(Wallpaper), SPIF_UPDATEINIFILE);
end;

{
procedure TMainForm.ChangeWallpaper(Wallpaper: String);
var
  Registry: TRegistry;
begin
  ShowMessage(Wallpaper);
  Registry := TRegistry.Create;
  Registry.RootKey := HKEY_CURRENT_USER;
  if Registry.OpenKey('Software\Microsoft\Internet Explorer\Desktop\General', False) then
    Registry.WriteString('BackupWallpaper', Wallpaper)
  else
    MessageDlg('Could not write to registry.', mtError, [mbOk], 0);
  Registry.Free;
end;
}
end.

